@@ -23,7 +23,6 @@ class Sensor:
     factor: int = attr.ib(default=None)
     path: Union[list, tuple] = attr.ib(default=None)
     enabled: bool = attr.ib(default=True)
-    entity_category: str = attr.ib(default=None)
     l10n_translate: bool = attr.ib(default=False)
     value: Any = attr.ib(default=None, init=False)
     key_idx: int = attr.ib(default=0, repr=False, init=False)
@@ -86,6 +85,12 @@ class Sensor:
         # Extract new value
         if isinstance(self.path, str):
             res = jmespath.search(self.path, res)
+
+            # SMA will return None instead of 0 if if no power is generated
+            # If we have extracted a path, we know the value was previously
+            # present and res can be set to 0
+            if res is None:
+                res = 0
         else:
             _LOGGER.debug(
                 "Sensor %s: No successful value decoded yet: %s", self.name, res
